Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nodejs/node.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
authorMichaël Zasso <targos@protonmail.com>2022-06-18 09:48:19 +0300
committerMichaël Zasso <targos@protonmail.com>2022-10-11 08:27:50 +0300
commitb5f1564880d24a26924a0aa5882c727e405b5281 (patch)
tree461903203aafe040c029d316c7be76040c6ef7d2 /tools
parent1acf0339dd3e68b38f50646cdcd50e83694a3b20 (diff)
test: rename always-opt flag to always-turbofan
Refs: https://chromium-review.googlesource.com/c/v8/v8/+/3610431 PR-URL: https://github.com/nodejs/node/pull/44741 Reviewed-By: Ben Noordhuis <info@bnoordhuis.nl> Reviewed-By: Jiawen Geng <technicalcute@gmail.com> Reviewed-By: James M Snell <jasnell@gmail.com>
Diffstat (limited to 'tools')
-rwxr-xr-xtools/test.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/test.py b/tools/test.py
index 788d68734fe..af276931cbf 100755
--- a/tools/test.py
+++ b/tools/test.py
@@ -1616,9 +1616,9 @@ def Main():
if options.check_deopts:
options.node_args.append("--trace-opt")
options.node_args.append("--trace-file-names")
- # --always-opt is needed because many tests do not run long enough for the
- # optimizer to kick in, so this flag will force it to run.
- options.node_args.append("--always-opt")
+ # --always-turbofan is needed because many tests do not run long enough for
+ # the optimizer to kick in, so this flag will force it to run.
+ options.node_args.append("--always-turbofan")
options.progress = "deopts"
if options.worker: